.. _pde-docs:

PDE
===

.. module::sympy.solvers.pde

User Functions
--------------
These are functions that are imported into the global namespace with ``from sympy import *``.  They are intended for user use.

pde_separate
^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_separate

pde_separate_add
^^^^^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_separate_add

pde_separate_mul
^^^^^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_separate_mul

pdsolve
^^^^^^^
.. autofunction:: sympy.solvers.pde::pdsolve

classify_pde
^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::classify_pde

checkpdesol
^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::checkpdesol

Hint Methods
------------
These functions are meant for internal use. However they contain useful information on the various solving methods.

pde_1st_linear_constant_coeff_homogeneous
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_1st_linear_constant_coeff_homogeneous

pde_1st_linear_constant_coeff
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_1st_linear_constant_coeff

pde_1st_linear_variable_coeff
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: sympy.solvers.pde::pde_1st_linear_variable_coeff

Information on the pde module
-----------------------------

.. automodule:: sympy.solvers.pde
